@@ -76,7 +76,7 @@ def update_tle_sets():
     other_sources = get_tle_sources()
 
     LOGGER.info("==Fetching TLEs==")
-    tles = fetch_all_tles(catalog_norad_ids, **other_sources)
+    tles = fetch_all_tles(list(catalog_norad_ids), **other_sources)
 
     for satellite in satellites:
         norad_id = satellite.satellite_entry.norad_cat_id
